@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
-# (c) Facebook, Inc. and its affiliates. Confidential and proprietary.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
+#
+# This source code is licensed under the BSD-style license found in the
+# LICENSE file in the root directory of this source tree.
 
 from __future__ import annotations
 
@@ -246,7 +249,6 @@ class SyncTrainer(FLTrainer):
                     )
 
                 # report training success rate and training time variance
-                # TODO write to metrics reporter T62638873
                 if rank == 0:
                     if (
                         self._timeout_simulator.sample_mean_per_user != 0
@@ -384,19 +386,15 @@ class SyncTrainer(FLTrainer):
             )
             self.server.receive_update_from_client(Message(client_delta, weight))
 
-        # TODO MM add multi-processing here for now we will do sequential
-        # with Pool(100) as workers:
-        #    workers.map(client_update, clients)
-
         t = time()
-        [update(client) for client in clients]
+        for client in clients:
+            update(client)
         self.logger.info(f"Collecting round's clients took {time() - t} s.")
 
         t = time()
         self.server.step()
         self.logger.info(f"Finalizing round took {time() - t} s.")
 
-        # TODO MM on adding asyn-trainer change api to get timeline
         t = time()
         self._report_train_metrics(
             model=self.global_model(),
@@ -453,10 +451,8 @@ class SyncTrainer(FLTrainer):
         """
         Calculates post-server aggregation metrics.
         """
-        # TODO do multiprocessing
-        # lines below internally change the state of metric reporter,
-        # no need to create extra reportable metrics.
-        [c.eval(model=model, metric_reporter=metric_reporter) for c in clients]
+        for client in clients:
+            client.eval(model=model, metric_reporter=metric_reporter)
 
         metrics = []
         if self.is_user_level_dp:
